import React from 'react';
import { isType } from 'graphql';
import { useExplorerNavStack, useSchema, } from '@graphiql/react';
import FieldDoc from './DocExplorer/FieldDoc';
import SchemaDoc from './DocExplorer/SchemaDoc';
import SearchBox from './DocExplorer/SearchBox';
import SearchResults from './DocExplorer/SearchResults';
import TypeDoc from './DocExplorer/TypeDoc';
export function DocExplorer(props) {
    var _a = useSchema(), fetchError = _a.fetchError, isFetching = _a.isFetching, schema = _a.schema, validationErrors = _a.validationErrors;
    var explorerContext = useExplorerNavStack();
    if (!explorerContext) {
        throw new Error('Tried to render the `DocExplorer` component without the necessary context. Make sure that the `ExplorerContextProvider` from `@graphiql/react` is rendered higher in the tree.');
    }
    var explorerNavStack = explorerContext.explorerNavStack, pop = explorerContext.pop, push = explorerContext.push, showSearch = explorerContext.showSearch;
    var navItem = explorerNavStack[explorerNavStack.length - 1];
    function handleClickType(type) {
        push({ name: type.name, def: type });
    }
    function handleClickField(field) {
        push({ name: field.name, def: field });
    }
    var content;
    if (fetchError) {
        content = React.createElement("div", { className: "error-container" }, "Error fetching schema");
    }
    else if (validationErrors) {
        content = (React.createElement("div", { className: "error-container" },
            "Schema is invalid: ",
            validationErrors[0].message));
    }
    else if (isFetching) {
        content = (React.createElement("div", { className: "spinner-container" },
            React.createElement("div", { className: "spinner" })));
    }
    else if (!schema) {
        content = React.createElement("div", { className: "error-container" }, "No Schema Available");
    }
    else if (navItem.search) {
        content = (React.createElement(SearchResults, { searchValue: navItem.search, withinType: navItem.def, schema: schema, onClickType: handleClickType, onClickField: handleClickField }));
    }
    else if (explorerNavStack.length === 1) {
        content = React.createElement(SchemaDoc, { schema: schema, onClickType: handleClickType });
    }
    else if (isType(navItem.def)) {
        content = (React.createElement(TypeDoc, { schema: schema, type: navItem.def, onClickType: handleClickType, onClickField: handleClickField }));
    }
    else {
        content = React.createElement(FieldDoc, { field: navItem.def, onClickType: handleClickType });
    }
    var shouldSearchBoxAppear = explorerNavStack.length === 1 ||
        (isType(navItem.def) && 'getFields' in navItem.def);
    var prevName;
    if (explorerNavStack.length > 1) {
        prevName = explorerNavStack[explorerNavStack.length - 2].name;
    }
    return (React.createElement("section", { className: "doc-explorer", key: navItem.name, "aria-label": "Documentation Explorer" },
        React.createElement("div", { className: "doc-explorer-title-bar" },
            prevName && (React.createElement("button", { className: "doc-explorer-back", onClick: pop, "aria-label": "Go back to " + prevName }, prevName)),
            React.createElement("div", { className: "doc-explorer-title" }, navItem.title || navItem.name),
            React.createElement("div", { className: "doc-explorer-rhs" }, props.children)),
        React.createElement("div", { className: "doc-explorer-contents" },
            shouldSearchBoxAppear && (React.createElement(SearchBox, { value: navItem.search, placeholder: "Search " + navItem.name + "...", onSearch: showSearch })),
            content)));
}
//# sourceMappingURL=DocExplorer.js.map